@@ -31,6 +31,7 @@ def transcribe_capture(
     model: str = "",
     enable_dictation: bool = False,
     enable_endpoint_detection: bool = False,
+    client_request_reference: str = "",
 ) -> Iterable[Result]:
     assert isinstance(capture_device, AbstractCaptureDevice)
     assert isinstance(client, SpeechClient)
@@ -51,6 +52,7 @@ def transcribe_capture(
     assert isinstance(model, str)
     assert isinstance(enable_dictation, bool)
     assert isinstance(enable_endpoint_detection, bool)
+    assert isinstance(client_request_reference, str)
 
     config = TranscriptionConfig()
     config.audio_format = "pcm_s16le"
@@ -72,6 +74,7 @@ def transcribe_capture(
     config.model = model
     config.enable_dictation = enable_dictation
     config.enable_endpoint_detection = enable_endpoint_detection
+    config.client_request_reference = client_request_reference
 
     if stop_event is None:
         stop_event = threading.Event()
@@ -104,6 +107,7 @@ def transcribe_microphone(
     model: str = "",
     enable_dictation: bool = False,
     enable_endpoint_detection: bool = False,
+    client_request_reference: str = "",
 ):
     return transcribe_capture(
         MicrophoneCaptureDevice(),
@@ -122,6 +126,7 @@ def transcribe_microphone(
         model,
         enable_dictation,
         enable_endpoint_detection,
+        client_request_reference,
     )
 
 
@@ -145,6 +150,7 @@ def transcribe_stream(
     enable_dictation: bool = False,
     enable_endpoint_detection: bool = False,
     include_nonfinal: bool = True,
+    client_request_reference: str = "",
 ) -> Iterable[Result]:
     assert isinstance(client, SpeechClient)
     assert isinstance(sample_rate_hertz, int)
@@ -167,6 +173,7 @@ def transcribe_stream(
     assert isinstance(enable_dictation, bool)
     assert isinstance(enable_endpoint_detection, bool)
     assert isinstance(include_nonfinal, bool)
+    assert isinstance(client_request_reference, str)
 
     config = TranscriptionConfig()
     config.audio_format = audio_format
@@ -189,5 +196,6 @@ def transcribe_stream(
     config.model = model
     config.enable_dictation = enable_dictation
     config.enable_endpoint_detection = enable_endpoint_detection
+    config.client_request_reference = client_request_reference
 
     yield from client.TranscribeStream(config, iter_audio)
